""
PROJECTNAME systeminformation .
PROJECTCATEGORY  .
PREREQUISITES URL.dll .


PROFILE
BEGIN
END

CLASS LocalSystem
INCLUDEDEF=1
CLASSMETHODS *
INSTANCEMETHODS *

CLASS OSVERSIONINFOEX
INCLUDEDEF=1
CLASSMETHODS *
INSTANCEMETHODS *
! !
Object subclass: #LocalSystem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: 'WinUserConstants '
	comment: ''
	category: ''!
Struct variableByteSubclass: #OSVERSIONINFOEX
	classVariableNames: ''
	poolDictionaries: ''
	comment: ''
	category: ''!

!LocalSystem class Windows methods 02:27 - 01/19/00!
getSystemDirectory
	"
	Answers the path of the Windows system directory.
	Return Value: 
		A String.
	"
	^FileStream getSystemDirectory! !

!LocalSystem class Hardware methods 10:30 - 01/13/00!
hardwareInfo
	"returns hardware informations"

	^WinApplication getHardwareInfoString! !

!LocalSystem class Network methods 08:39 - 08/01/00!
isOffline
	"
	Determines whether or not the system is connected to the Internet.
	Return Values:
		Returns true if the local system is not currently connected to the Internet.
		Returns false if the local system is connected to the Internet or if no 
		attempt has yet been made to connect to the Internet.		
	"
	^(WINAPI InetIsOffline: NULL) == TRUE! !

!LocalSystem class Network methods 08:39 - 08/01/00!
isOnline
	"
	Returns true if the computer is connected to the internet.
	"
	
	^self isOffline not! !

!LocalSystem class Hardware methods 02:27 - 01/19/00!
isSlowProcessor
	"returns true if the computer has a low-end (slow) processor, 
       false otherwise.
	" 
	
	^(WINAPI GetSystemMetrics: SM_SLOWMACHINE) == TRUE! !

!LocalSystem class Network methods 10:30 - 01/13/00!
localHostName
	"returns the name of the local host"

	^self queryWinSockFor: 'LocalHostName'.! !

!LocalSystem class Network methods 10:30 - 01/13/00!
localIP
	"returns the systems local IP number"

	^self queryWinSockFor: 'LocalIP'.! !

!LocalSystem class Operations methods 07:39 - 08/01/00!
lockWorkstation
	"
	Locks the workstation's display, protecting it from unauthorized use.
	Parameters
		This function has no parameters.
	Return Values
 		A Boolean.
	" 
	^WINAPI LockWorkStation! !

!LocalSystem class Mouse methods 08:33 - 03/27/01!
mouseAvailable
	"returns true if a mouse is available, otherwise false"
	
	^self numberOfMouseButtons ~~ 0! !

!LocalSystem class Mouse methods 02:27 - 01/19/00!
mouseInstalled
	"returns the number of mouse buttons, or zero if no mouse is installed"

	(WINAPI GetSystemMetrics: SM_MOUSEPRESENT) == FALSE ifFalse: [^true].
	^false! !

!LocalSystem class Mouse methods 02:27 - 01/19/00!
mouseWheelPresent
	"returns true if a mouse with a wheel is installed, false otherwise
	 Windows NT4.0 and later, Windows 98
	"

	(WINAPI GetSystemMetrics: SM_MOUSEWHEELPRESENT) == FALSE ifFalse: [^true].
	^false! !

!LocalSystem class Network methods 02:27 - 01/19/00!
networkPresent
	"returns true if network is present"

	^(WINAPI GetSystemMetrics: SM_NETWORK) & 1 = 1! !

!LocalSystem class Screen methods 08:33 - 03/27/01!
numberOfDisplayMonitors
	"returns the number of display monitors attached to the desktop
	 Useful for Win98 and Win2000		
	"

	^WINAPI GetSystemMetrics: SM_CMONITORS! !

!LocalSystem class Mouse methods 01:17 - 01/19/00!
numberOfMouseButtons
	"returns the number of mouse buttons, or zero if no mouse is installed"

	^WINAPI GetSystemMetrics: SM_CMOUSEBUTTONS! !

!LocalSystem class Windows methods 08:33 - 03/27/01!
printBootType
	"
	Returns the bot type as a string.	
	"

	(WINAPI GetSystemMetrics: SM_CLEANBOOT) 
	case: 0 perform: [^'Normal']
	case: 1 perform: [^'Fail-safe'] 
	case: 2 perform: [^'Fail-safe with network'].! !

!LocalSystem class Printing methods 07:52 - 08/02/00!
printLocalSystemInfo
	"
	self printLocalSystemInfo
	"
	|stream|
	stream := (String new: 1024) asStream.
	stream nextPutAll: 'System:\n\t';
		nextPutAll: self hardwareInfo;
		nextPutAll: '\n\tisSlowProcessor: ',self isSlowProcessor printString;
		
		nextPutAll: '\n\nMouse:';		
		nextPutAll: '\n\tnumberOfMouseButtons: ',self numberOfMouseButtons printString;
		nextPutAll: '\n\tmouseWheelPresent: ',self mouseWheelPresent printString;

		nextPutAll: '\n\nNetwork:';
		nextPutAll: '\n\tnetworkPresent: ',self networkPresent printString;
		nextPutAll: '\n\tisOffline: ',self isOffline printString;
		nextPutAll: '\n\tlocalHostName: ',self localHostName printString;
		nextPutAll: '\n\tlocalIP: ',self localIP printString;
		
		nextPutAll: '\n\nScreen:';
		nextPutAll: '\n\tnumberOfDisplayMonitors: ',self numberOfDisplayMonitors printString;
		nextPutAll: (String wsprintf: '\n\tscreenSize: %dx%d' _with: self screenWidth _with: self screenHeight);
		
		nextPutAll: '\n\nWindows:';
		nextPutAll: '\n\tSystemDirectory: ',self getSystemDirectory;
		nextPutAll: '\n\twasNormalBoot: ',self wasNormalBoot printString;
		nextPutAll: '\n\twasFailSafeBoot: ',self wasFailSafeBoot printString;
		nextPutAll: '\n\twasFailSafeBootWithNetwork: ',self wasFailSafeBootWithNetwork printString;
		
		nextPutAll: '\n\nSmalltalk:';
		nextPutAll: '\n\tsmalltalkVersion: ',self smalltalkVersion;
		nextPutAll: '\n\tsmalltalkEdition: ',self smalltalkEdition. 
		
	^stream contents! !

!LocalSystem class Private methods 10:30 - 01/13/00!
queryWinSockFor: aProperty
	"returns the value of aProperty in the WinSock object model"

	|winSock property|
	winSock := IDispatch createObject: 'MSWinsock.Winsock'.
	property := winSock getProperty: aProperty.
	winSock Release.
	^property! !

!LocalSystem class Screen methods 01:17 - 01/19/00!
screenHeight	
	"returns the vertical screen size"

	^WINAPI GetSystemMetrics: SM_CYSCREEN! !

!LocalSystem class Screen methods 01:17 - 01/19/00!
screenSize
	"returns the current screen size
 	 Return Value:
		A point representing the current screen size
	" 
	|x y|
	x := self screenWidth.
	y := self screenHeight.
	^x@y! !

!LocalSystem class Screen methods 01:17 - 01/19/00!
screenWidth	
	"returns the horizontal screen size"

	^WINAPI GetSystemMetrics: SM_CXSCREEN! !

!LocalSystem class Smalltalk methods 10:30 - 01/13/00!
smalltalkEdition
	"returns the smalltalk edition"	

	^Compiler getEditionString! !

!LocalSystem class Smalltalk methods 10:30 - 01/13/00!
smalltalkVersion
	"returns the smalltalk version"	

	^Compiler getVersionString! !

!LocalSystem class Windows methods 01:17 - 01/19/00!
wasFailSafeBoot
	"Returns true if the system was started fail-safe, false otherwise.
	 Fail-safe boot (also called SafeBoot) bypasses the user's startup files.	
	"

	(WINAPI GetSystemMetrics: SM_CLEANBOOT) == 1 ifTrue: [^true].
	^false! !

!LocalSystem class Windows methods 01:17 - 01/19/00!
wasFailSafeBootWithNetwork
	"Returns true if the system was started fail-safe with network boot, 
       false otherwise.
	 Fail-safe boot (also called SafeBoot) bypasses the user's startup files.	
	"

	(WINAPI GetSystemMetrics: SM_CLEANBOOT) == 2 ifTrue: [^true].
	^false! !

!LocalSystem class Windows methods 01:17 - 01/19/00!
wasNormalBoot
	"Returns true if the system was started normal"

	(WINAPI GetSystemMetrics: SM_CLEANBOOT) == 0 ifTrue: [^true].
	^false! !

!OSVERSIONINFOEX class Operations methods 07:44 - 07/31/00!
getProductType
	"
	Indicates additional information about the system. Indicates additional information about the system. 
	Return Value:
		One of the following values: 
		VER_NT_WORKSTATION			Windows 2000 Professional
		VER_NT_DOMAIN_CONTROLLER		Windows 2000 domain controller
		VER_NT_SERVER				Windows 2000 Server
	" 
	^self getVersionEx wProductType! !

!OSVERSIONINFOEX class Operations methods 07:14 - 08/02/00!
getProductTypeString
	"
	Returns a String representing the product type of the OS.
	"
	self getProductType 
	 	case: VER_NT_WORKSTATION       perform: [^'Windows 2000 Professional']
		case: VER_NT_DOMAIN_CONTROLLER perform: [^'Windows 2000 Domain Controller']
		case: VER_NT_SERVER            perform: [^'Windows 2000 Server'].				 
	^EmptyString! !

!OSVERSIONINFOEX class Operations methods 07:44 - 07/31/00!
getSuiteMask
	"
	Returns a set of bit flags that identify the product suites available on 
	the system. This can be a combination of the following values:
	 	VER_SUITE_BACKOFFICE 			Microsoft BackOffice components are installed. 
		VER_SUITE_DATACENTER 			Windows 2000 DataCenter Server is installed. 
		VER_SUITE_ENTERPRISE    		Windows 2000 Advanced Server is installed. 
		VER_SUITE_SMALLBUSINESS 		Microsoft Small Business Server is installed. 
		VER_SUITE_SMALLBUSINESS_RESTRICTED  Microsoft Small Business Server is installed 
								with the restrictive client license in force. 
		VER_SUITE_TERMINAL 			Terminal Services is installed.
	" 
	^self getVersionEx wSuiteMask! !

!OSVERSIONINFOEX class Operations methods 07:14 - 08/02/00!
getVersionEx
	| osVersion |
	osVersion := OSVERSIONINFOEX localNew.
	osVersion dwOSVersionInfoSize: ##(OSVERSIONINFOEX sizeInBytes). 
	WINAPI GetVersionExA: osVersion.
	^osVersion! !

!OSVERSIONINFOEX class Operations methods 07:44 - 07/31/00!
getVersionString
	| osVersion szVersion |
	osVersion := self getVersionEx.
	szVersion := String wsprintfA: '%d.%d (build %d) %s' asStringA
		_with: osVersion dwMajorVersion
		_with: osVersion dwMinorVersion
		_with: osVersion dwBuildNumber loword
		_with: osVersion szCSDVersion.
	^(osVersion dwPlatformId == VER_PLATFORM_WIN32_NT ifTrue: [
		'Microsoft Windows NT ' asStringA
	]
	ifFalse: [ 'Microsoft Windows ' asStringA]),szVersion! !

!OSVERSIONINFOEX class .EXTERN methods 07:44 - 07/31/00!
initialize
	"
	Private - Initialize the definition dictionaries.
	"
	super initialize.
	self
		addAccessor: #dwOSVersionInfoSize size: DWORD;
		addAccessor: #dwMajorVersion      size: DWORD;
		addAccessor: #dwMinorVersion      size: DWORD;
		addAccessor: #dwBuildNumber       size: DWORD;
		addAccessor: #dwPlatformId        size: DWORD;
		addAccessor: #szCSDVersion        size: 128;
		addAccessor: #wServicePackMajor   size: WORD;
		addAccessor: #wServicePackMinor   size: WORD;
		addAccessor: #wSuiteMask          size: WORD;
		addAccessor: #wProductType        size: BYTE;
		addAccessor: #wReserved           size: BYTE.! !

Compiler addCatDescription: 'Screen' text: 'Screen'.
Compiler addCatDescription: 'Operations' text: 'Operations
Operations on this object'.
Compiler addCatDescription: 'Smalltalk' text: 'Smalltalk'.
Compiler addCatDescription: '.EXTERN' text: '.EXTERN
Includes the source, but discards the code when the image is compressed.'.
Compiler addCatDescription: 'Mouse' text: 'Mouse'.
Compiler addCatDescription: 'Network' text: 'Network'.
Compiler addCatDescription: 'Windows' text: 'Windows'.
Compiler addCatDescription: 'Printing' text: 'Printing
Print a textual representation of the receiver.
'.
Compiler addCatDescription: 'Private' text: 'Private
Private methods.'.
Compiler addCatDescription: 'Hardware' text: 'Hardware'.!
